@@ -453,7 +453,7 @@ by_regex <- function(..., .grepl_args = list(), ignore_na = TRUE) {
 #'
 #' `by_colorspace()` can be used to set background, border or
 #' text colors, visually differentiating high or low values.
-#' 
+#'
 #' @param ... Colors
 #' @param range Numeric endpoints. If `NULL`, these are determined from the data.
 #' @param na_color Color to return for `NA` values. Can be `NA` itself.
@@ -545,7 +545,7 @@ by_function <- function (inner_fn, ignore_na = TRUE) {
 #'
 #' @details
 #' Within the formulas, the variable `.` will refer to the content of
-#' `ht[rows, cols]`, after conversion by [as.matrix()].
+#' `ht[rows, cols]`, after conversion to a vector.
 #'
 #' `case_when` returns `NA` when no formula LHS is matched. To avoid this, set a
 #' default in the last formula: `TRUE ~ default`.
@@ -579,9 +579,13 @@ by_cases <- function (..., ignore_na = TRUE) {
   case_fn <- function (ht, rows, cols, current) {
     res <- current
     myenv <- new.env()
-    assign(".",  as.matrix(ht[rows, cols]), envir = myenv)
+    selection <- as.matrix(ht[rows, cols])
+    dim <- dim(selection)
+    if (utils::packageVersion("dplyr") >= "1.1.0") selection <- as.vector(selection)
+    assign(".", selection, envir = myenv)
     cases <- lapply(cases, stats::as.formula, env = myenv)
     vals <- dplyr::case_when(!!! cases)
+    vals <- array(vals, dim = dim)
     res[] <- vals
     res <- maybe_ignore_na(res, current, ignore_na)
     res
